@@ -50,9 +50,9 @@ test_that("yields equal BFr0 estimates binomial equality constraints", {
   output_total  <- binom_bf_informed(factor_levels=factor_levels, Hr=Hr, a=a, bf_type = 'BFr0',
                                      b=b, x=x, n=n, seed=2020)
   output_total2  <- binom_bf_informed(factor_levels=factor_levels, Hr=Hr1, a=a, bf_type = 'BFr0',
-                                     b=b, x=x, n=n)
+                                     b=b, x=x, n=n, seed=2020)
   output_total3  <- binom_bf_informed(factor_levels=factor_levels, Hr=Hr2, a=a, bf_type = 'BFr0',
-                                     b=b, x=x, n=n)
+                                     b=b, x=x, n=n, seed=2020)
   
   expect_equal(output_total$bf_list, list(bf_type = "BFr0", bf = structure(list(
     LogBFr0 = 8.04741180815038, BF0r = 0.000319928889188777, 
@@ -78,15 +78,14 @@ test_that("yields equal BFr0 estimates binomial equality constraints", {
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  -1L), class = "data.frame")))
   
   expect_equal(output_total3$bf_list, list(bf_type = "BFr0", bf = structure(list(
-    LogBFr0 = 0, BF0r = 1, BFr0 = 1), class = "data.frame", row.names = c(NA, 
-                                                                          -1L)), bf0_table = structure(list(LogBFe0 = 0.843962315683342, 
-                                                                                                            BFe0 = 2.32556336143926, BF0e = 0.430003334495739), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                    -1L)), bfr_table = structure(list(LogBFer = 0.843962315683342, 
-                                                                                                                                                                                                                                      BFer = 2.32556336143926, BFre = 0.430003334495739), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                              -1L)), error_measures = structure(list(re2 = 0, cv = 0, percentage = "0%"), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                                                                                                                                              -1L)), logBFe_equalities = structure(list(logBFe_equalities = 0.843962315683342), row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              -1L), class = "data.frame")))
-  
+    LogBFr0 = 5.32221334327146, BF0r = 0.00488193635739305, BFr0 = 204.836754679449), class = "data.frame", row.names = c(NA, 
+                                                                                                                          -1L)), bf0_table = structure(list(LogBFe0 = 6.16617565895481, 
+                                                                                                                                                            BFe0 = 476.360851758647, BF0e = 0.00209924891247499), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                      -1L)), bfr_table = structure(list(LogBFer = 0.843962315683342, 
+                                                                                                                                                                                                                                                                                        BFer = 2.32556336143926, BFre = 0.430003334495739), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                -1L)), error_measures = structure(list(re2 = 0, cv = 0, percentage = "0%"), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                -1L)), logBFe_equalities = structure(list(logBFe_equalities = 0.843962315683342), row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                -1L), class = "data.frame")))
   })
 
 context("evaluate Bayes factors for equality constraints - Multinomial")
@@ -97,7 +96,7 @@ test_that("yields equal BF estimates multinomial equality constraints", {
   data("lifestresses")
   a             <- rep(1, nrow(lifestresses))
   x             <- lifestresses$stress.freq
-  output_total  <- mult_bf_equality(x, a)
+  output_total  <- suppressWarnings(mult_bf_equality(x, a))
   
   expect_equal(output_total$bf, structure(list(LogBFe0 = 3.29976435023366, 
                                                BFe0 = 27.1062505863656, BF0e = 0.0368918599351766), 
@@ -136,12 +135,13 @@ test_that("yields equal BFr0 estimates multinomial equality constraints", {
                                                                                                                  -1L)))
   
   expect_equal(output_total3$bf_list, list(bf_type = "LogBFr0", 
-                                           bf = structure(list(LogBFr0 = 0, BF0r = 1, BFr0 = 1), class = "data.frame", row.names = c(NA, 
-                                                                                                                                     -1L)), bf0_table = structure(list(LogBFe0 = 54.8269578439159, 
-                                                                                                                                                                       BFe0 = 6.4721004805001e+23, BF0e = 1.54509344070432e-24), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                                                                                     -1L)), bfr_table = structure(list(LogBFer = 54.8269578439159, 
-                                                                                                                                                                                                                                                                                                       BFer = 6.4721004805001e+23, BFre = 1.54509344070432e-24), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                                                                                                     -1L)), error_measures = structure(list(re2 = 0, cv = 0, percentage = "0%"), class = "data.frame", row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     -1L)), logBFe_equalities = structure(list(logBFe_equalities = 54.8269578439159), row.names = c(NA, 
-                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    -1L), class = "data.frame")))
-  })
+                                           bf = structure(list(LogBFr0 = 88.0440230090771, BF0r = 5.79384193223835e-39, 
+                                                               BFr0 = 1.72597045569324e+38), class = "data.frame", row.names = c(NA, 
+                                                                                                                                 -1L)), bf0_table = structure(list(LogBFe0 = 142.870980852993, 
+                                                                                                                                                                   BFe0 = 1.11706542156212e+62, BF0e = 8.95202716597913e-63), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                                  -1L)), bfr_table = structure(list(LogBFer = 54.8269578439159, 
+                                                                                                                                                                                                                                                                                                    BFer = 6.4721004805001e+23, BFre = 1.54509344070432e-24), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                                  -1L)), error_measures = structure(list(re2 = 0, cv = 0, percentage = "0%"), class = "data.frame", row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  -1L)), logBFe_equalities = structure(list(logBFe_equalities = 54.8269578439159), row.names = c(NA, 
+                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 -1L), class = "data.frame")))
+})
